==> adminer-2.3.2.tbz: www/adminer/adminer/lang/sk.inc.php <==
<?php
$translations = array(
	'Login' => 'Prihlásiť sa',
	'Logout successful.' => 'Odhlásenie prebehlo v poriadku.',
	'Invalid credentials.' => 'Neplatné prihlasovacie údaje.',
	'Server' => 'Server',
	'Username' => 'Používateľ',
	'Password' => 'Heslo',
	'Select database' => 'Vybrať databázu',
	'Invalid database.' => 'Nesprávna databáza.',
	'Create new database' => 'Vytvoriť novú databázu',
	'Table has been dropped.' => 'Tabuľka bola odstránená.',
	'Table has been altered.' => 'Tabuľka bola zmenená.',
	'Table has been created.' => 'Tabuľka bola vytvorená.',
	'Alter table' => 'Zmeniť tabuľku',
	'Create table' => 'Vytvoriť tabuľku',
	'Table name' => 'Názov tabuľky',
	'engine' => 'úložisko',
	'collation' => 'porovnávanie',
	'Column name' => 'Názov stĺpca',
	'Type' => 'Typ',
	'Length' => 'Dĺžka',
	'Auto Increment' => 'Auto Increment',
	'Options' => 'Voľby',
	'Save' => 'Uložiť',
	'Drop' => 'Odstrániť',
	'Database has been dropped.' => 'Databáza bola odstránená.',
	'Database has been created.' => 'Databáza bola vytvorená.',
	'Database has been renamed.' => 'Databáza bola premenovaná.',
	'Database has been altered.' => 'Databáza bola zmenená.',
	'Alter database' => 'Zmeniť databázu',
	'Create database' => 'Vytvoriť databázu',
	'SQL command' => 'SQL príkaz',
	'Dump' => 'Export',
	'Logout' => 'Odhlásiť',
	'database' => 'databáza',
	'Use' => 'Vybrať',
	'No tables.' => 'Žiadne tabuľky.',
	'select' => 'vypísať',
	'Create new table' => 'Vytvoriť novú tabuľku',
	'Item has been deleted.' => 'Položka bola vymazaná.',
	'Item has been updated.' => 'Položka bola aktualizovaná.',
	'Item has been inserted.' => 'Položka bola vložená.',
	'Edit' => 'Upraviť',
	'Insert' => 'Vložiť',
	'Save and insert next' => 'Uložiť a vložiť ďalší',
	'Delete' => 'Zmazať',
	'Database' => 'Databáza',
	'Routines' => 'Procedúry',
	'Indexes have been altered.' => 'Indexy boli zmenené.',
	'Indexes' => 'Indexy',
	'Alter indexes' => 'Zmeniť indexy',
	'Add next' => 'Pridať ďalší',
	'Language' => 'Jazyk',
	'Select' => 'Vypísať',
	'New item' => 'Nová položka',
	'Search' => 'Vyhľadať',
	'Sort' => 'Zotriediť',
	'descending' => 'zostupne',
	'Limit' => 'Limit',
	'No rows.' => 'Žiadne riadky.',
	'Action' => 'Akcia',
	'edit' => 'upraviť',
	'Page' => 'Stránka',
	'Query executed OK, %d row(s) affected.' => array('Príkaz prebehol v poriadku, bol zmenený %d záznam.', 'Príkaz prebehol v poriadku boli zmenené %d záznamy.', 'Príkaz prebehol v poriadku bolo zmenených %d záznamov.'),
	'Error in query' => 'Chyba v dotaze',
	'Execute' => 'Vykonať',
	'Table' => 'Tabuľka',
	'Foreign keys' => 'Cudzie kľúče',
	'Triggers' => 'Triggery',
	'View' => 'Pohľad',
	'Unable to select the table' => 'Tabuľku sa nepodarilo vypísať',
	'Invalid CSRF token. Send the form again.' => 'Neplatný token CSRF. Odošlite formulár znova.',
	'Comment' => 'Komentár',
	'Default values' => 'Východzie hodnoty',
	'Show column comments' => 'Zobraziť komentáre stĺpcov',
	'%d byte(s)' => array('%d bajt', '%d bajty', '%d bajtov'),
	'No commands to execute.' => 'Žiadne príkazy na vykonanie.',
	'Unable to upload a file.' => 'Súbor sa nepodarilo nahrať.',
	'File upload' => 'Nahranie súboru',
	'File uploads are disabled.' => 'Nahrávánie súborov nie je povolené.',
	'Routine has been called, %d row(s) affected.' => array('Procedúra bola zavolaná, bol zmenený %d záznam.', 'Procedúra bola zavolaná, boli zmenené %d záznamy.', 'Procedúra bola zavolaná, bolo zmenených %d záznamov.'),
	'Call' => 'Zavolať',
	'No MySQL extension' => 'Žiadne MySQL rozšírenie',
	'None of the supported PHP extensions (%s) are available.' => 'Nie je dostupné žiadne z podporovaných rozšírení (%s).',
	'Session support must be enabled.' => 'Session premenné musia byť povolené.',
	'Session expired, please login again.' => 'Session vypršala, prihláste sa prosím znova.',
	'Text length' => 'Dĺžka textov',
	'Foreign key has been dropped.' => 'Cudzí kľúč bol odstránený.',
	'Foreign key has been altered.' => 'Cudzí kľúč bol zmenený.',
	'Foreign key has been created.' => 'Cudzí kľúč bol vytvorený.',
	'Foreign key' => 'Cudzí kľúč',
	'Target table' => 'Cieľová tabuľka',
	'Change' => 'Zmeniť',
	'Source' => 'Zdroj',
	'Target' => 'Cieľ',
	'Add column' => 'Pridať stĺpec',
	'Alter' => 'Zmeniť',
	'Add foreign key' => 'Pridať cudzí kľúč',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Typ indexu',
	'Column (length)' => 'Stĺpec (dĺžka)',
	'View has been dropped.' => 'Pohľad bol odstránený.',
	'View has been altered.' => 'Pohľad bol zmenený.',
	'View has been created.' => 'Pohľad bol vytvorený.',
	'Alter view' => 'Zmeniť pohľad',
	'Create view' => 'Vytvoriť pohľad',
	'Name' => 'Názov',
	'Process list' => 'Zoznam procesov',
	'%d process(es) have been killed.' => array('Bol ukončený %d proces.', 'Boli ukončené %d procesy.', 'Bolo ukončených %d procesov.'),
	'Kill' => 'Ukončiť',
	'Parameter name' => 'Názov parametra',
	'Database schema' => 'Schéma databázy',
	'Create procedure' => 'Vytvoriť procedúru',
	'Create function' => 'Vytvoriť funkciu',
	'Routine has been dropped.' => 'Procedúra bola odstránená.',
	'Routine has been altered.' => 'Procedúra bola zmenená.',
	'Routine has been created.' => 'Procedúra bola vytvorená.',
	'Alter function' => 'Zmeniť funkciu',
	'Alter procedure' => 'Zmeniť procedúru',
	'Return type' => 'Návratový typ',
	'Add trigger' => 'Pridať trigger',
	'Trigger has been dropped.' => 'Trigger bol odstránený.',
	'Trigger has been altered.' => 'Trigger bol zmenený.',
	'Trigger has been created.' => 'Trigger bol vytvorený.',
	'Alter trigger' => 'Zmeniť trigger',
	'Create trigger' => 'Vytvoriť trigger',
	'Time' => 'Čas',
	'Event' => 'Udalosť',
	'MySQL version: %s through PHP extension %s' => 'Verzia MySQL: %s cez PHP rozšírenie %s',
	'%d row(s)' => array('%d riadok', '%d riadky', '%d riadkov'),
	'~ %s' => '~ %s',
	'Remove' => 'Odobrať',
	'Are you sure?' => 'Naozaj?',
	'Privileges' => 'Oprávnenia',
	'Create user' => 'Vytvoriť používateľa',
	'User has been dropped.' => 'Používateľ bol odstránený.',
	'User has been altered.' => 'Používateľ bol zmenený.',
	'User has been created.' => 'Používateľ bol vytvorený.',
	'Hashed' => 'Zahašované',
	'Column' => 'Stĺpec',
	'Routine' => 'Procedúra',
	'Grant' => 'Povoliť',
	'Revoke' => 'Zakázať',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Príliš veľké POST dáta. Zmenšite dáta alebo zvýšte hodnotu konfiguračej direktívy %s.',
	'Logged as: %s' => 'Prihlásený ako: %s',
	'Move up' => 'Presunúť hore',
	'Move down' => 'Presunúť dolu',
	'Functions' => 'Funkcie',
	'Aggregation' => 'Agregácia',
	'Export' => 'Export',
	'Output' => 'Výstup',
	'open' => 'otvoriť',
	'save' => 'uložiť',
	'Format' => 'Formát',
	'Tables' => 'Tabuľky',
	'Data' => 'Dáta',
	'Event has been dropped.' => 'Udalosť bola odstránená.',
	'Event has been altered.' => 'Udalosť bola zmenená.',
	'Event has been created.' => 'Udalosť bola vytvorená.',
	'Alter event' => 'Upraviť udalosť',
	'Create event' => 'Vytvoriť udalosť',
	'At given time' => 'V stanovený čas',
	'Every' => 'Každých',
	'Events' => 'Udalosti',
	'Schedule' => 'Plán',
	'Start' => 'Začiatok',
	'End' => 'Koniec',
	'Status' => 'Stav',
	'On completion preserve' => 'Po dokončení zachovat',
	'Save and continue edit' => 'Uložiť a pokračovať v úpravách',
	'original' => 'originál',
	'Tables have been truncated.' => 'Tabuľka bola vyprázdnená',
	'Tables have been moved.' => 'Tabuľka bola presunutá',
	'Tables have been dropped.' => 'Tabuľka bola odstránená',
	'Tables and views' => 'Tabuľky a pohľady',
	'Engine' => 'Typ',
	'Collation' => 'Porovnávanie',
	'Data Length' => 'Veľkosť dát',
	'Index Length' => 'Veľkosť indexu',
	'Data Free' => 'Voľné miesto',
	'Rows' => 'Riadky',
	',' => ' ',
	'Analyze' => 'Analyzovať',
	'Optimize' => 'Optimalizovať',
	'Check' => 'Skontrolovať',
	'Repair' => 'Opraviť',
	'Truncate' => 'Vyprázdniť',
	'Move to other database' => 'Presunúť do inej databázy',
	'Move' => 'Presunúť',
	'%d item(s) have been affected.' => '%d položiek bolo ovplyvnených.',
	'whole result' => 'celý výsledok',
	'Clone' => 'Klonovať',
	'Partition by' => 'Rozdeliť podľa',
	'Partitions' => 'Oddiely',
	'Partition name' => 'Názov oddielu',
	'Values' => 'Hodnoty',
	'%d row(s) have been imported.' => array('Bol importovaný %d záznam.', 'Boli importované %d záznamy.', 'Bolo importovaných %d záznamov.'),
	'CSV Import' => 'Import CSV',
	'Import' => 'Import',
	'Show structure' => 'Štruktúra tabuľky',
	'Select data' => 'Vypísať tabuľku',
	'Stop on error' => 'Zastaviť pri chybe',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Bol prekročený maximálny počet povolených polí. Zvýšte prosím %s a %s.',
	'(anywhere)' => '(kdekoľvek)',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 'd.m.[rrrr]',
	'History' => 'História',
	'Variables' => 'Premenné',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Zdrojové a cieľové stĺpce musia mať rovnaký datový typ, nad cieľovými stĺpcami musí byť definovaný index a odkazované dáta musia existovať.',
	'E-mail' => 'E-mail',
	'From' => 'Odosielateľ',
	'Subject' => 'Predmet',
	'Send' => 'Odoslať',
	'%d e-mail(s) have been sent.' => array('Bol odoslaný %d e-mail.', 'Boli odoslané %d e-maily.', 'Bolo odoslaných %d e-mailov.'),
	'Run file' => 'Spustiť súbor',
	'Numbers' => 'Čísla',
	'Date and time' => 'Dátum a čas',
	'Strings' => 'Reťazce',
	'Binary' => 'Binárne',
	'Lists' => 'Zoznamy',
	'Relations' => 'Vzťahy',
	'Maximum allowed file size is %sB.' => 'Maximálna povolená veľkosť súboru je %sB.',
	'Clear' => 'Vyčistiť',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Súbor %s na webovom serveri',
	'File does not exist.' => 'Súbor neexistuje.',
	'Permanent login' => 'Trvalé prihlásenie',
	'%d in total' => '%d celkom',
);

==> adminer-3.1.0_1.tbz: www/adminer/adminer/lang/sk.inc.php <==
<?php
$translations = array(
	'Login' => 'Prihlásiť sa',
	'Logout successful.' => 'Odhlásenie prebehlo v poriadku.',
	'Invalid credentials.' => 'Neplatné prihlasovacie údaje.',
	'Server' => 'Server',
	'Username' => 'Používateľ',
	'Password' => 'Heslo',
	'Select database' => 'Vybrať databázu',
	'Invalid database.' => 'Nesprávna databáza.',
	'Create new database' => 'Vytvoriť novú databázu',
	'Table has been dropped.' => 'Tabuľka bola odstránená.',
	'Table has been altered.' => 'Tabuľka bola zmenená.',
	'Table has been created.' => 'Tabuľka bola vytvorená.',
	'Alter table' => 'Zmeniť tabuľku',
	'Create table' => 'Vytvoriť tabuľku',
	'Table name' => 'Názov tabuľky',
	'engine' => 'úložisko',
	'collation' => 'porovnávanie',
	'Column name' => 'Názov stĺpca',
	'Type' => 'Typ',
	'Length' => 'Dĺžka',
	'Auto Increment' => 'Auto Increment',
	'Options' => 'Voľby',
	'Save' => 'Uložiť',
	'Drop' => 'Odstrániť',
	'Databases have been dropped.' => 'Databázy boli odstránené.',
	'Database has been dropped.' => 'Databáza bola odstránená.',
	'Database has been created.' => 'Databáza bola vytvorená.',
	'Database has been renamed.' => 'Databáza bola premenovaná.',
	'Database has been altered.' => 'Databáza bola zmenená.',
	'Alter database' => 'Zmeniť databázu',
	'Create database' => 'Vytvoriť databázu',
	'SQL command' => 'SQL príkaz',
	'Dump' => 'Export',
	'Logout' => 'Odhlásiť',
	'database' => 'databáza',
	'Use' => 'Vybrať',
	'No tables.' => 'Žiadne tabuľky.',
	'select' => 'vypísať',
	'Create new table' => 'Vytvoriť novú tabuľku',
	'Item has been deleted.' => 'Položka bola vymazaná.',
	'Item has been updated.' => 'Položka bola aktualizovaná.',
	'Item%s has been inserted.' => 'Položka%s bola vložená.',
	'Edit' => 'Upraviť',
	'Insert' => 'Vložiť',
	'Save and insert next' => 'Uložiť a vložiť ďalší',
	'Delete' => 'Zmazať',
	'Database' => 'Databáza',
	'Routines' => 'Procedúry',
	'Indexes have been altered.' => 'Indexy boli zmenené.',
	'Indexes' => 'Indexy',
	'Alter indexes' => 'Zmeniť indexy',
	'Add next' => 'Pridať ďalší',
	'Language' => 'Jazyk',
	'Select' => 'Vypísať',
	'New item' => 'Nová položka',
	'Search' => 'Vyhľadať',
	'Sort' => 'Zotriediť',
	'descending' => 'zostupne',
	'Limit' => 'Limit',
	'No rows.' => 'Žiadne riadky.',
	'Action' => 'Akcia',
	'edit' => 'upraviť',
	'Page' => 'Stránka',
	'Query executed OK, %d row(s) affected.' => array('Príkaz prebehol v poriadku, bol zmenený %d záznam.', 'Príkaz prebehol v poriadku boli zmenené %d záznamy.', 'Príkaz prebehol v poriadku bolo zmenených %d záznamov.'),
	'Error in query' => 'Chyba v dotaze',
	'Execute' => 'Vykonať',
	'Table' => 'Tabuľka',
	'Foreign keys' => 'Cudzie kľúče',
	'Triggers' => 'Triggery',
	'View' => 'Pohľad',
	'Unable to select the table' => 'Tabuľku sa nepodarilo vypísať',
	'Invalid CSRF token. Send the form again.' => 'Neplatný token CSRF. Odošlite formulár znova.',
	'Comment' => 'Komentár',
	'Default values' => 'Východzie hodnoty',
	'%d byte(s)' => array('%d bajt', '%d bajty', '%d bajtov'),
	'No commands to execute.' => 'Žiadne príkazy na vykonanie.',
	'Unable to upload a file.' => 'Súbor sa nepodarilo nahrať.',
	'File upload' => 'Nahranie súboru',
	'File uploads are disabled.' => 'Nahrávánie súborov nie je povolené.',
	'Routine has been called, %d row(s) affected.' => array('Procedúra bola zavolaná, bol zmenený %d záznam.', 'Procedúra bola zavolaná, boli zmenené %d záznamy.', 'Procedúra bola zavolaná, bolo zmenených %d záznamov.'),
	'Call' => 'Zavolať',
	'No extension' => 'Žiadne rozšírenie',
	'None of the supported PHP extensions (%s) are available.' => 'Nie je dostupné žiadne z podporovaných rozšírení (%s).',
	'Session support must be enabled.' => 'Session premenné musia byť povolené.',
	'Session expired, please login again.' => 'Session vypršala, prihláste sa prosím znova.',
	'Text length' => 'Dĺžka textov',
	'Foreign key has been dropped.' => 'Cudzí kľúč bol odstránený.',
	'Foreign key has been altered.' => 'Cudzí kľúč bol zmenený.',
	'Foreign key has been created.' => 'Cudzí kľúč bol vytvorený.',
	'Foreign key' => 'Cudzí kľúč',
	'Target table' => 'Cieľová tabuľka',
	'Change' => 'Zmeniť',
	'Source' => 'Zdroj',
	'Target' => 'Cieľ',
	'Add column' => 'Pridať stĺpec',
	'Alter' => 'Zmeniť',
	'Add foreign key' => 'Pridať cudzí kľúč',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Typ indexu',
	'Column (length)' => 'Stĺpec (dĺžka)',
	'View has been dropped.' => 'Pohľad bol odstránený.',
	'View has been altered.' => 'Pohľad bol zmenený.',
	'View has been created.' => 'Pohľad bol vytvorený.',
	'Alter view' => 'Zmeniť pohľad',
	'Create view' => 'Vytvoriť pohľad',
	'Name' => 'Názov',
	'Process list' => 'Zoznam procesov',
	'%d process(es) have been killed.' => array('Bol ukončený %d proces.', 'Boli ukončené %d procesy.', 'Bolo ukončených %d procesov.'),
	'Kill' => 'Ukončiť',
	'Parameter name' => 'Názov parametra',
	'Database schema' => 'Schéma databázy',
	'Create procedure' => 'Vytvoriť procedúru',
	'Create function' => 'Vytvoriť funkciu',
	'Routine has been dropped.' => 'Procedúra bola odstránená.',
	'Routine has been altered.' => 'Procedúra bola zmenená.',
	'Routine has been created.' => 'Procedúra bola vytvorená.',
	'Alter function' => 'Zmeniť funkciu',
	'Alter procedure' => 'Zmeniť procedúru',
	'Return type' => 'Návratový typ',
	'Add trigger' => 'Pridať trigger',
	'Trigger has been dropped.' => 'Trigger bol odstránený.',
	'Trigger has been altered.' => 'Trigger bol zmenený.',
	'Trigger has been created.' => 'Trigger bol vytvorený.',
	'Alter trigger' => 'Zmeniť trigger',
	'Create trigger' => 'Vytvoriť trigger',
	'Time' => 'Čas',
	'Event' => 'Udalosť',
	'%s version: %s through PHP extension %s' => 'Verzia %s: %s cez PHP rozšírenie %s',
	'%d row(s)' => array('%d riadok', '%d riadky', '%d riadkov'),
	'Remove' => 'Odobrať',
	'Are you sure?' => 'Naozaj?',
	'Privileges' => 'Oprávnenia',
	'Create user' => 'Vytvoriť používateľa',
	'User has been dropped.' => 'Používateľ bol odstránený.',
	'User has been altered.' => 'Používateľ bol zmenený.',
	'User has been created.' => 'Používateľ bol vytvorený.',
	'Hashed' => 'Zahašované',
	'Column' => 'Stĺpec',
	'Routine' => 'Procedúra',
	'Grant' => 'Povoliť',
	'Revoke' => 'Zakázať',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Príliš veľké POST dáta. Zmenšite dáta alebo zvýšte hodnotu konfiguračej direktívy %s.',
	'Logged as: %s' => 'Prihlásený ako: %s',
	'Move up' => 'Presunúť hore',
	'Move down' => 'Presunúť dolu',
	'Functions' => 'Funkcie',
	'Aggregation' => 'Agregácia',
	'Export' => 'Export',
	'Output' => 'Výstup',
	'open' => 'otvoriť',
	'save' => 'uložiť',
	'Format' => 'Formát',
	'Tables' => 'Tabuľky',
	'Data' => 'Dáta',
	'Event has been dropped.' => 'Udalosť bola odstránená.',
	'Event has been altered.' => 'Udalosť bola zmenená.',
	'Event has been created.' => 'Udalosť bola vytvorená.',
	'Alter event' => 'Upraviť udalosť',
	'Create event' => 'Vytvoriť udalosť',
	'At given time' => 'V stanovený čas',
	'Every' => 'Každých',
	'Events' => 'Udalosti',
	'Schedule' => 'Plán',
	'Start' => 'Začiatok',
	'End' => 'Koniec',
	'Status' => 'Stav',
	'On completion preserve' => 'Po dokončení zachovat',
	'Save and continue edit' => 'Uložiť a pokračovať v úpravách',
	'original' => 'originál',
	'Tables have been truncated.' => 'Tabuľka bola vyprázdnená.',
	'Tables have been moved.' => 'Tabuľka bola presunutá.',
	'Tables have been dropped.' => 'Tabuľka bola odstránená.',
	'Tables and views' => 'Tabuľky a pohľady',
	'Engine' => 'Typ',
	'Collation' => 'Porovnávanie',
	'Data Length' => 'Veľkosť dát',
	'Index Length' => 'Veľkosť indexu',
	'Data Free' => 'Voľné miesto',
	'Rows' => 'Riadky',
	',' => ' ',
	'Analyze' => 'Analyzovať',
	'Optimize' => 'Optimalizovať',
	'Check' => 'Skontrolovať',
	'Repair' => 'Opraviť',
	'Truncate' => 'Vyprázdniť',
	'Move to other database' => 'Presunúť do inej databázy',
	'Move' => 'Presunúť',
	'%d item(s) have been affected.' => '%d položiek bolo ovplyvnených.',
	'whole result' => 'celý výsledok',
	'Clone' => 'Klonovať',
	'Partition by' => 'Rozdeliť podľa',
	'Partitions' => 'Oddiely',
	'Partition name' => 'Názov oddielu',
	'Values' => 'Hodnoty',
	'%d row(s) have been imported.' => array('Bol importovaný %d záznam.', 'Boli importované %d záznamy.', 'Bolo importovaných %d záznamov.'),
	'CSV Import' => 'Import CSV',
	'Import' => 'Import',
	'Stop on error' => 'Zastaviť pri chybe',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Bol prekročený maximálny počet povolených polí. Zvýšte prosím %s a %s.',
	'anywhere' => 'kdekoľvek',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 'd.m.[rrrr]',
	'History' => 'História',
	'Variables' => 'Premenné',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Zdrojové a cieľové stĺpce musia mať rovnaký datový typ, nad cieľovými stĺpcami musí byť definovaný index a odkazované dáta musia existovať.',
	'E-mail' => 'E-mail',
	'From' => 'Odosielateľ',
	'Subject' => 'Predmet',
	'Send' => 'Odoslať',
	'%d e-mail(s) have been sent.' => array('Bol odoslaný %d e-mail.', 'Boli odoslané %d e-maily.', 'Bolo odoslaných %d e-mailov.'),
	'Run file' => 'Spustiť súbor',
	'Numbers' => 'Čísla',
	'Date and time' => 'Dátum a čas',
	'Strings' => 'Reťazce',
	'Binary' => 'Binárne',
	'Lists' => 'Zoznamy',
	'Relations' => 'Vzťahy',
	'Maximum allowed file size is %sB.' => 'Maximálna povolená veľkosť súboru je %sB.',
	'Clear' => 'Vyčistiť',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Súbor %s na webovom serveri',
	'File does not exist.' => 'Súbor neexistuje.',
	'Permanent login' => 'Trvalé prihlásenie',
	'%d in total' => '%d celkom',
	'Search data in tables' => 'Vyhľadať dáta v tabuľkách',
	'Alter schema' => 'Pozmeniť schému',
	'Create schema' => 'Vytvoriť schému',
	'Schema has been dropped.' => 'Schéma bola odstránená.',
	'Schema has been created.' => 'Schéma bola vytvorená.',
	'Schema has been altered.' => 'Schéma bola zmenená.',
	'schema' => 'schéma',
	'Schema' => 'Schéma',
	'Sequences' => 'Sekvencia',
	'Create sequence' => 'Vytvoriť sekvenciu',
	'Sequence has been dropped.' => 'Sekvencia bola odstránená.',
	'Sequence has been created.' => 'Sekvencia bola vytvorená.',
	'Sequence has been altered.' => 'Sekvencia bola zmenená.',
	'Alter sequence' => 'Pozmeniť sekvenciu',
	'User types' => 'Užívateľské typy',
	'Create type' => 'Vytvoriť typ',
	'Type has been dropped.' => 'Typ bol odstránený.',
	'Type has been created.' => 'Typ bol vytvorený.',
	'Alter type' => 'Pozmeniť typ',
	'Double click on a value to modify it.' => 'Dvojkliknite na políčko, ktoré chcete zmeniť.',
	'Increase Text length to modify this value.' => 'Pre zmenu tejto hodnoty zvýšte Dĺžku textov.',
	'Use edit link to modify this value.' => 'Pre zmenu tejto hodnoty použite odkaz upraviť.',
	'last' => 'posledný',
	'From server' => 'Zo serveru',
	'System' => 'Systém',
	'Show structure' => 'Zobraziť štruktúru',
	'Select data' => 'Vypísať dáta',
	'empty' => 'prázdne',
	'Network' => 'Sieť',
	'Geometry' => 'Geometria',
	'File exists.' => 'Súbor existuje.',
	'Attachments' => 'Prílohy',
	'%d query(s) executed OK.' => array('Bol vykonaný %d dotaz.', 'Boli vykonané %d dotazy.', 'Bolo vykonaných %d dotazov.'),
	'Show only errors' => 'Zobraziť iba chyby',
	'Last page' => 'Posledná stránka',
	'Refresh' => 'Obnoviť',
	'Invalid schema.' => 'Neplatné schéma.',
	'Please use one of the extensions %s.' => 'Prosím vyberte jednu z koncoviek %s.',
	'now' => 'teraz',
	'ltr' => 'ltr',
);
